@@ -1,7 +1,7 @@
 from .Logger import get_logger
 from .Utils import get_number_rows_cols_for_fig, venn_names, get_number_of_non_na_values, plot_annotate_line,\
     get_intersection_and_unique, dict_depth, get_legend_elements, get_plot_name_suffix, get_analysis_design, fill_dict,\
-    default_to_regular, get_non_na_percentage, DataDict, format_docstrings, add_end_docstrings
+    default_to_regular, get_non_na_percentage, DataDict, format_docstrings, add_end_docstrings, make_contrasts
 
 __all__ = [
     "get_intersection_and_unique",
@@ -20,4 +20,5 @@ __all__ = [
     "DataDict",
     "format_docstrings",
     "add_end_docstrings",
+    "make_contrasts",
 ]
