@@ -7,6 +7,7 @@ import matplotlib.pyplot as plt
 import matplotlib.gridspec as gridspec
 import matplotlib.colors as colors
 import matplotlib.cm as cm
+import matplotlib.lines as mlines
 from matplotlib.backends.backend_pdf import PdfPages
 from matplotlib.collections import LineCollection
 from adjustText import adjust_text
@@ -260,8 +261,8 @@ def split_plot(n_rows, n_cols, figsize=(7, 7), plot_name="", data=None, plot_fn=
 @save_csvs({"unique_g1": "csv_significant/volcano_plot_data_{g1}_vs_{g2}_unique_{g1}",
             "unique_g2": "csv_significant/volcano_plot_data_{g1}_vs_{g2}_unique_{g2}"})
 def save_volcano_results(
-        volcano_data: pd.DataFrame, unique_g1: pd.Series = None, unique_g2: pd.Series = None, g1: str = "group1",
-        g2: str = "group2", adj_pval: bool = True, intensity_label: str = "Intensity",
+        volcano_data: pd.DataFrame, interesting_proteins, unique_g1: pd.Series = None, unique_g2: pd.Series = None, g1: str = "group1",
+        g2: str = "group2", adj_pval: bool = False, intensity_label: str = "Intensity",
         show_suptitle: bool = True, pval_threshold: float = 0.05, fchange_threshold: float = 2,
         scatter_size: float = 10, n_labelled_proteins: int = 10, **kwargs
 ) -> Tuple[plt.Figure, Tuple[plt.Axes, plt.Axes, plt.Axes]]:
@@ -307,6 +308,12 @@ def save_volcano_results(
     else:
         col = "pval"
 
+    # given pathway mapping(s)/proteins of interest create a list later used to be annotated in the volcano plot
+    POI_vals = []
+    if interesting_proteins.values():
+        all_pathway_proteins = set.union(*(set(x) for x in interesting_proteins.values()))
+        POI_vals = volcano_data[volcano_data.index.isin(list(all_pathway_proteins))]
+
     def get_volcano_significances(fchange, pval, pval_threshold, fchange_threshold):
         if pval > pval_threshold or abs(fchange) < np.log2(fchange_threshold):
             return "ns"
@@ -317,6 +324,10 @@ def save_volcano_results(
         else:
             raise ValueError(f"heisenbug: fold change: {fchange}, p value: {pval}")
 
+
+    g1_name = g1.replace("_", " ")
+    g2_name = g2.replace("_", " ")
+
     # add the measured regulation to the data based on the given thresholds
     volcano_data["regulation"] = [get_volcano_significances(log_fold_change, p_val, pval_threshold, fchange_threshold)
                                   for log_fold_change, p_val in zip(volcano_data["logFC"], volcano_data[col])]
@@ -330,7 +341,7 @@ def save_volcano_results(
     save_csv_fn(save_path, csv_name, volcano_data[volcano_data[col] < 0.05])
 
     significance_to_color = {"ns": "gray", "up": "red", "down": "blue"}
-    significance_to_label = {"ns": "non-significant", "up": f"upregulated in {g2}", "down": f"upregulated in {g1}"}
+    significance_to_label = {"ns": "non-significant", "up": f"higher in  {g2_name}", "down": f"higher in  {g1_name}"}
 
     # plot
     fig = plt.figure(figsize=(7, 7))
@@ -377,9 +388,9 @@ def save_volcano_results(
         ax.axvline(np.log2(fchange_threshold), **axline_kwargs, ymin=y_percentage, ymax=1)
     # plot unique values with mean intensity at over maximum
     ax_unique_down.scatter([0] * len(unique_g1), unique_g1, s=scatter_size, color="dodgerblue",
-                           label=f"{len(unique_g1)} unique in {g1}")
+                           label=f"{len(unique_g1)} unique in  {g1_name}")
     ax_unique_up.scatter([0] * len(unique_g2), unique_g2, s=scatter_size, color="coral",
-                         label=f"{len(unique_g2)} unique in {g2}")
+                         label=f"{len(unique_g2)} unique in  {g2_name}")
     # adjust bounds for unique axis
     ymin_down, ymax_down = ax_unique_down.get_ybound()
     ymin_up, ymax_up = ax_unique_up.get_ybound()
@@ -409,9 +420,18 @@ def save_volcano_results(
         (volcano_data["logFC"] < -np.log2(fchange_threshold)) & (volcano_data[col] < 0.05)
     ].sort_values(by=[col], ascending=True).head(n_labelled_proteins)
     significant = pd.concat([significant_upregulated, significant_downregulated])
+
     texts = []
-    for log_fold_change, p_val, gene_name in zip(significant["logFC"], significant[col], significant.index):
-        texts.append(ax.text(log_fold_change, -np.log10(p_val), gene_name, ha="center", va="center", fontsize=8))
+    # if list for proteins of interest (pathway list chosen) is given, annotate those proteins,
+    # otherwise annotate most significant proteins
+    if len(POI_vals) > 0:
+        for log_fold_change, p_val, gene_name in zip(POI_vals["logFC"], POI_vals[col], POI_vals.index):
+            texts.append(ax.text(log_fold_change, -np.log10(p_val), gene_name, ha="center", va="center", fontsize=8,
+                                 color="black"))
+    else:
+        for log_fold_change, p_val, gene_name in zip(significant["logFC"], significant[col], significant.index):
+            texts.append(ax.text(log_fold_change, -np.log10(p_val), gene_name, ha="center", va="center", fontsize=8,
+                                 color="black"))
     adjust_text(texts, arrowprops=dict(width=0.15, headwidth=0, color='gray', alpha=0.6), ax=ax)
 
     # save the final result
@@ -459,15 +479,24 @@ def save_pca_results(
         warnings.warn("Normalizing not possible when pca_fit is None")
     elif normalize and pca_fit is not None:
         singular_values = pca_fit.singular_values_
+
+    if pca_fit is not None:
+        pca_var = np.round(pca_fit.explained_variance_ratio_ * 100, decimals=1)
+        pca_var = [f"{var} %" for var in pca_var]
+    else:
+        pca_var = ["nan" for _ in range(len(pca_fit.n_components_))]
+
     if n_components == 2:
         fig, axarr = plt.subplots(1, 1, figsize=(14, 14))
-        ax = axarr[0]
+        ax = axarr
         ax.scatter(
             pca_data.loc["PC_1"] / singular_values[0],
             pca_data.loc["PC_2"] / singular_values[1],
+            s = 100,
             c=[base_color_map.get(name, "blue") for name in pca_data.columns.get_level_values(0)])
-        ax.set_xlabel("PC_1")
-        ax.set_ylabel("PC_2")
+        ax.set_xlabel("PC 1 - {0}".format(pca_var[0]), fontsize = 22)
+        ax.set_ylabel("PC 2 - {0}".format(pca_var[1]), fontsize = 22)
+        ax.tick_params(axis = "both", labelsize = 18)
     else:
         fig, axarr = plt.subplots(n_components, n_components, figsize=(14, 14))
         for row in range(n_components):
@@ -479,14 +508,16 @@ def save_pca_results(
                     ax.scatter(
                         pca_data.loc[f"PC_{row_pc}"] / singular_values[row],
                         pca_data.loc[f"PC_{col_pc}"] / singular_values[col],
+                        s = 100,
                         c=[base_color_map.get(name, "blue") for name in pca_data.columns.get_level_values(0)])
-                    ax.set_xlabel(f"PC_{row_pc}")
-                    ax.set_ylabel(f"PC_{col_pc}")
+                    ax.set_xlabel(f"PC {row_pc} - {0}".format(pca_var[0]), fontsize = 22)
+                    ax.set_ylabel(f"PC {col_pc} - {0}".format(pca_var[1]), fontsize = 22)
+                    ax.tick_params(axis = "both", labelsize = 18)
 
     if show_suptitle:
-        fig.suptitle(intensity_label, fontsize="xx-large")
+        fig.suptitle(intensity_label, fontsize=30)
     legend_elements = get_legend_elements(labels=pca_data.columns.get_level_values(0).unique(), color_map=base_color_map)
-    fig.legend(handles=legend_elements, bbox_to_anchor=(1.02, 0.5), loc="center left", frameon=False, fontsize=20)
+    fig.legend(handles=legend_elements, bbox_to_anchor=(1.02, 0.5), loc="center left", frameon=False, fontsize = 20)
     fig.tight_layout(rect=[0, 0.03, 1, 0.95])
     return fig, axarr
 
@@ -528,7 +559,7 @@ def save_pathway_analysis_results(
     plt.close("all")
     level_keys = list(protein_intensities.columns.get_level_values(0).unique())
     n_rows, n_cols = get_number_rows_cols_for_fig(protein_intensities.index)
-    fig, axarr = plt.subplots(n_rows, n_cols, figsize=(n_cols * 4, int(n_rows * len(level_keys) / 1.5)))
+    fig, axarr = plt.subplots(n_rows, n_cols, figsize=(n_cols * 5, int(n_rows * len(level_keys) / 1.2)))
     result_color_map = {value: f"C{i}" for i, value in enumerate(level_keys)}
     result_color_map.update(color_map if color_map is not None else {})
     if show_suptitle:
@@ -539,6 +570,10 @@ def save_pathway_analysis_results(
         ax.set_title(protein)
         ax.set_ylim((-1, len(level_keys)))
         ax.set_yticks([i for i in range(len(level_keys))])
+        level_keys_labels = [key.replace("_", " ") for key in level_keys]
+        if len(level_keys_labels) == 0:
+            level_keys_labels = level_keys
+        ax.set_yticklabels(level_keys_labels)
         ax.set_yticklabels(level_keys)
         ax.set_xlabel(intensity_label)
     fig.tight_layout(rect=[0, 0.03, 1, 0.95])
@@ -554,7 +589,8 @@ def save_pathway_analysis_results(
             xmin, xmax = ax.get_xbound()
             ax.set_xlim(right=xmax * (1 + to_annotate.shape[0] * 0.015))
             for i, (index, pval) in enumerate(to_annotate.items()):
-                plot_annotate_line(ax, level_keys.index(index[0]), level_keys.index(index[1]), xmax * (1 + i * 0.015) - 0.005, pval)
+                plot_annotate_line(ax, level_keys.index(index[0]), level_keys.index(index[1]),
+                                   xmax * (1 + i * 0.015) - 0.005, pval, maxasterix = 3)
 
         fig.tight_layout(rect=[0, 0.03, 1, 0.95])
 
@@ -617,7 +653,7 @@ def save_boxplot_results(
 @format_docstrings(kwargs=_get_path_and_name_kwargs_doc)
 def save_relative_std_results(
         intensities: pd.DataFrame, experiment_name: str, intensity_label: str = "Intensity",
-        show_suptitle: bool = False, bins=(10, 20, 30), cmap: dict = None, **kwargs
+        show_suptitle: bool = True, bins=(10, 20, 30), cmap: dict = None, **kwargs
 ) -> Tuple[plt.Figure, plt.Axes]:
     """
     Relative standard deviations of passed intensities with color marking based on the specified bins and color map.
@@ -661,9 +697,11 @@ def save_relative_std_results(
     plot_colors = pd.Series([default_cm.get(x, "black") for x in inds], index=relative_std_percent.index)
     color_counts = {color: (plot_colors == color).sum() for color in plot_colors.unique()}
 
-    fig, ax = plt.subplots(1, 1, figsize=(14, 7))
+    fig, ax = plt.subplots(1, 1, figsize=(6, 4))
     ax.scatter(intensities.mean(axis=1), relative_std_percent, c=plot_colors, marker="o", s=(2 * 72. / fig.dpi) ** 2,
                alpha=0.8)
+
+    experiment_name = experiment_name.replace("_", "  ")
     if show_suptitle:
         fig.suptitle(experiment_name)
     ax.set_xlabel(f"Mean {intensity_label}")
@@ -709,18 +747,31 @@ def save_detection_counts_results(
     if show_suptitle:
         fig.suptitle(f"Detection counts from {intensity_label}")
 
+    global_max = counts.max().max()
+
+
     for (pos, ax), col in zip(np.ndenumerate(axarr), counts.columns):
         col_data = counts.loc[:, col]
         col_data = col_data[~pd.isna(col_data)]
+        col_name  = col.replace("_", " ")
 
-        ax.set_title(f"{col},\ntotal detected: {int(col_data.sum())}")
+        ax.set_title(f"{col_name} \n total detected: {int(col_data.sum())}")
         ax.barh(col_data.index, col_data, color="skyblue")
+
+        if len(col_data) in range(1,9):
+            fsize = 11
+        elif len(col_data) in range(9,13):
+            fsize = 7
+        else:
+            fsize = 5
+
         for y, value in zip(col_data.index, col_data):
             ax.text(col_data.max() / 2, y, value,
-                    verticalalignment='center', horizontalalignment='center')
+                    verticalalignment='center', horizontalalignment='center', fontsize = fsize)
 
         ax.set_yticks(col_data.index)
-        ax.set_yticklabels([f"detected in {i} replicates" for i in col_data.index])
+        ax.set_yticklabels([f"detected in {i} replicates" for i in col_data.index], fontsize=fsize)
+        ax.set_xlim(0, global_max + global_max*0.05)
         ax.set_xlabel("Counts")
 
     fig.tight_layout(rect=[0, 0.03, 1, 0.95])
@@ -978,7 +1029,8 @@ def save_intensities_heatmap_result(
 
     y_lim = ax.get_ylim()
     ax.set_yticks(np.linspace(0, len(intensities.columns) - 1, len(intensities.columns)))
-    ax.set_yticklabels(intensities.columns)
+    labels = [sample.replace("_", " ") for sample in intensities.columns.values]
+    ax.set_yticklabels(labels= labels)
     ax.set_ylim(*y_lim)
 
     fig.tight_layout(rect=[0, 0.03, 1, 0.95])
@@ -1013,19 +1065,36 @@ def save_detected_proteins_per_replicate_results(
     if show_suptitle:
         fig.suptitle(f"Number of detected proteins from {intensity_label}")
 
+    global_max = 0
+    for key, df in all_heights.items():
+        local_max = df.max()
+        if local_max > global_max:
+            global_max = local_max
+
     for experiment, (pos, ax) in zip(all_heights.keys(), np.ndenumerate(axarr)):
         experiment_heights = all_heights[experiment]
         mean_height = experiment_heights[1:].mean()
         y_pos = [x for x in range(len(experiment_heights))]
         ax.barh(y_pos, experiment_heights, color="skyblue")
 
+        if len(experiment_heights) in range(1,10):
+            fsize = 11
+        elif len(experiment_heights) in range(10,16):
+            fsize = 7
+        else:
+            fsize = 5
+
         for y, value in zip(y_pos, experiment_heights):
             ax.text(experiment_heights[0] / 2, y, value,
-                    verticalalignment='center', horizontalalignment='center')
-        ax.set_title(experiment)
+                    verticalalignment='center', horizontalalignment='center', fontsize = fsize)
+        labels = experiment_heights.index.values
+        labels = [label.replace((experiment + "_"), "").replace("_", " ") for label in labels]
+
+        ax.set_title(experiment.replace("_", "  "))
         ax.axvline(mean_height, linestyle="--", color="black", alpha=0.6)
         ax.set_yticks([i for i in range(len(experiment_heights.index))])
-        ax.set_yticklabels(experiment_heights.index)
+        ax.set_yticklabels(labels, fontsize = fsize)
+        ax.set_xlim(0, global_max + global_max*0.02)
         ax.set_xlabel("Counts")
     fig.tight_layout(rect=[0, 0.03, 1, 0.95])
     return fig, axarr
@@ -1085,8 +1154,11 @@ def save_intensity_histogram_results(
         else:
             bins = np.logspace(np.log2(np.nanmin(intensities.values)), np.log2(np.nanmax(intensities.values)), n_bins, base=2)
 
-        ax.set_title(col)
-        ax.hist(intensities.T, bins=bins, histtype=histtype, label=labels, color=color)
+        col_name = col.replace("_", "  ")
+        labels = [label.replace("_", " ") for label in labels]
+
+        ax.set_title(col_name)
+        ax.hist(intensities, bins=bins, histtype=histtype, label=labels, color=color)
 
         if compare_to_remaining:
             remaining = hist_data.drop(col, axis=1)
@@ -1094,7 +1166,7 @@ def save_intensity_histogram_results(
             # remaining = remaining[intensities.notna()]
             ax.hist(remaining, bins=bins, histtype="step", alpha=0.5)
         if "Log_2" not in intensity_label:
-            ax.set_xscale("log", basex=2)
+            ax.set_xscale("log", base=2)
         ax.set_xlabel(intensity_label)
         ax.set_ylabel("Counts")
 
@@ -1123,7 +1195,7 @@ def save_scatter_replicates_results(
 
     """
     plt.close("all")
-    fig, ax = plt.subplots(1, 1, figsize=(7, 7))
+    fig, ax = plt.subplots(1, 1, figsize=(6, 6))
 
     if show_suptitle:
         fig.suptitle()
@@ -1134,14 +1206,16 @@ def save_scatter_replicates_results(
         corr_mask = np.logical_and(x1.notna(), x2.notna())
         plot_mask = np.logical_or(x1.notna(), x2.notna())
         exp = r"$r^{2}$"
+        rep1 = rep1.replace("_", "  ")
+        rep2 = rep2.replace("_", "  ")
         ax.scatter(x1.fillna(x2.min() * 0.95)[plot_mask], x2.fillna(x2.min() * 0.95)[plot_mask],
-                   label=f"{rep1} vs {rep2}, "
-                         fr"{exp}: {stats.pearsonr(x1[corr_mask], x2[corr_mask])[0] ** 2:.4f}",
-                   alpha=0.5, marker=".")
+                       label=f"{rep1}  vs  {rep2},  "
+                        fr"{exp}: {stats.pearsonr(x1[corr_mask], x2[corr_mask])[0] ** 2:.4f}",
+                        alpha=0.5, marker=".")
         ax.set_xlabel(intensity_label)
         ax.set_ylabel(intensity_label)
 
-    fig.legend(frameon=False)
+    fig.legend(frameon=False,  bbox_to_anchor=(1.02, 0.5), loc="center left")
     if "Log_2" not in intensity_label:
         ax.set_xscale("log")
         ax.set_yscale("log")
@@ -1189,43 +1263,55 @@ def save_rank_results(
     # get all proteins that are not part of any pathway
     non_pathway_proteins = found_proteins - all_pathway_proteins
     # get all proteins that are part of any pathway
-    pathway_proteins = found_proteins & all_pathway_proteins
-    rank_identified_proteins = [dic[protein][0] for protein in pathway_proteins]
-    # plot the non pathway proteins
-    x = [dic[protein][0] for protein in non_pathway_proteins]
-    y = [dic[protein][1] for protein in non_pathway_proteins]
 
-    fig, ax = plt.subplots(1, 1, figsize=(14, 7))
-    ax.scatter(x, y, c=f"darkgray", s=10, alpha=0.3, marker=".", label="no pathway")
+    # plot the non pathway proteins
+    x = [dic[protein][0] for protein in non_pathway_proteins]  # rank
+    y = [dic[protein][1] for protein in non_pathway_proteins]  # intensity
+
+    fig, ax = plt.subplots(1, 1, figsize=(6, 4))
+    ax.scatter(x, y, c="darkgray", s=12, alpha=0.3, marker=".", label="no pathway")
+
     # plot all proteins of a specific pathway
+    legend_text = []
+    handles = []
     for i, (pathway, proteins) in enumerate(interesting_proteins.items()):
         proteins = set(proteins) & found_proteins
-        x = [dic[protein][0] for protein in proteins]
-        y = [dic[protein][1] for protein in proteins]
-        ax.scatter(x, y, c=f"C{i}", s=80, alpha=0.6, marker=".", label=pathway)
+        if proteins:
+            x = [dic[protein][0] for protein in proteins]  # the rank of each protein
+            y = [dic[protein][1] for protein in proteins]  # the intensity of each protein
+            ax.scatter(x, y, c=f"C{i}", s=80, alpha=0.8, marker=".", label=pathway.replace("_", " "))
 
-    # only if more than 0 proteins are identified
-    if rank_identified_proteins:
-        median_pathway_rank = int(np.median(rank_identified_proteins))
-        median_intensity = rank_data.iloc[median_pathway_rank]
-        xmin, xmax = ax.get_xbound()
-        xm = (median_pathway_rank + abs(xmin)) / (abs(xmax) + abs(xmin))
-        ymin, ymax = ax.get_ybound()
-        ym = (median_intensity - ymin) / (ymax - ymin)
-        # plot the median rank and intensity at that rank
-        ax.axvline(median_pathway_rank, ymax=ym, linestyle="--", color="black", alpha=0.6)
-        ax.axhline(median_intensity, xmax=xm, linestyle="--", color="black", alpha=0.6)
-        ax.text(xmin * 0.9, median_intensity * 0.9,
-                f"median rank: {median_pathway_rank} ({median_pathway_rank / len(rank_data) * 100 :.1f}%) "
-                f"with intensity: {median_intensity:.2E}",  # TODO case for log and non log
-                verticalalignment="top", horizontalalignment="left")
+            median_pathway_rank = int(np.median(x))
+            median_intensity = rank_data.iloc[median_pathway_rank]
+            xmin, xmax = ax.get_xbound()
+            xm = (median_pathway_rank + abs(xmin)) / (abs(xmax) + abs(xmin))
+            ymin, ymax = ax.get_ybound()
+            ym = (median_intensity - ymin) / (ymax - ymin)
+            # plot the median rank and intensity at that rank
+            ax.axvline(median_pathway_rank, ymax=ym, linestyle="--", color=f"C{i}", alpha=0.6)
+            ax.axhline(median_intensity, xmax=xm, linestyle="--", color=f"C{i}", alpha=0.6)
+            text = f"{pathway} : median rank: {median_pathway_rank / len(rank_data) * 100 :.1f}% "
+            legend_text.append(text)
+            handle = mlines.Line2D([], [], color=f"C{i}", marker='.', markersize=10, label=text, linewidth=0)
+            handles.append(handle)
+            # ax.text(xmin * 0.9, median_intensity * 0.9, text, verticalalignment="top", horizontalalignment="left")
+            # f"median rank: {median_pathway_rank} ({median_pathway_rank / len(rank_data) * 100 :.1f}%) "
+            # f"with intensity: {median_intensity:.2E}",  # TODO case for log and non log
 
+
+    legend_text.append("no pathway assigned")
+    handle = mlines.Line2D([], [], color="lightgray", marker='.', markersize=10, label=text, linewidth=0)
+    handles.append(handle)
+
+    exp_name = full_name.replace("_", " ")
     if "Log_2" not in intensity_label:
         ax.set_yscale("log")
-    ax.set_xlabel("Protein rank")
-    ax.set_ylabel(f"{full_name} mean")
-
-    fig.legend(bbox_to_anchor=(1.02, 0.5), loc="center left")
+    ax.set_xlabel("Protein rank", size=10)
+    # ax.set_ylabel(f"{exp_name} mean Log_2 intensity")
+    ax.set_ylabel(intensity_label, size=10)
+    ax.set_title(f"{exp_name} mean", weight="bold", size="14")
+    # legend_text = [pathway for pathway in interesting_proteins.keys()]
+    fig.legend(labels=legend_text, handles=handles, bbox_to_anchor=(1.02, 0.5), loc="center left")
     fig.tight_layout(rect=[0, 0.03, 1, 0.95])
     return fig, ax
 
@@ -1276,19 +1362,23 @@ def save_experiment_comparison_results(
         fig, ax = plot
     else:
         plt.close("all")
-        fig, ax = plt.subplots(1, 1, figsize=(7, 7))
+        fig, ax = plt.subplots(1, 1, figsize=(6, 6))
 
     exp = r"$r^{2}$"
+    sample1 = sample1.replace("_", " ")
+    sample2 = sample2.replace("_", " ")
+
     ax.scatter(protein_intensities_sample1, protein_intensities_sample2, s=8, alpha=0.6, marker=".",
-               label=f"{sample1} vs {sample2}, {exp}: {r[0] ** 2:.4f}")
+               label=f"{sample1}  vs  {sample2}, {exp}: {r[0] ** 2:.4f}")
     ax.scatter(exclusive_sample1, [np.min(protein_intensities_sample2) * 0.95] * exclusive_sample1.shape[0],
-               s=8, alpha=0.6, marker=".", label=f"exclusive for {sample1}")
+               s=8, alpha=0.6, marker=".", label=f"exclusive for  {sample1}")
     ax.scatter([np.min(protein_intensities_sample1) * 0.95] * exclusive_sample2.shape[0], exclusive_sample2,
-               s=8, alpha=0.6, marker=".", label=f"exclusive for {sample2}")
+               s=8, alpha=0.6, marker=".", label=f"exclusive for  {sample2}")
+
+    ax.set_xlabel(sample1, weight = "bold", labelpad= 10)
+    ax.set_ylabel(sample2, weight = "bold", labelpad = 10)
+    fig.legend(frameon=False, bbox_to_anchor=(1.02, 0.5), loc="center left")
 
-    ax.set_xlabel(sample1)
-    ax.set_ylabel(sample2)
-    fig.legend(frameon=False)
     if "Log_2" not in intensity_label:
         ax.set_xscale("log")
         ax.set_yscale("log")
@@ -1325,34 +1415,53 @@ def save_go_analysis_results(
         {kwargs}
 
     """
-    # TODO also create table
-    # TODO move labels to bars, remove legend
+
     plt.close("all")
-    fig, ax = plt.subplots(1, 1, figsize=(7, int(len(heights) * len(go_analysis_gene_names) / 3)))
 
-    bar_width = 0.25
-    for i, experiment in enumerate(heights):
-        y_pos = np.array([(i + (len(heights) + 1) * x) * bar_width for x in range(len(go_analysis_gene_names))])
-        ax.barh(y_pos, heights[experiment], height=bar_width, edgecolor='white', label=experiment)
-        for x, y, text in zip(heights[experiment], y_pos, test_results[experiment]):
-            if text > 0.05:
+    go_analysis_gene_names = [go_term.replace("_", " ") for go_term in go_analysis_gene_names]
+
+    heights_df = pd.DataFrame(data=heights, index=go_analysis_gene_names)
+    test_results_df = pd.DataFrame(data=test_results, index=go_analysis_gene_names)
+    # save go analysis data
+    save_path, csv_name = get_path_and_name_from_kwargs(name = "tables/go_analysis_data", **kwargs)
+    save_csv_fn(save_path, csv_name, heights_df)
+    save_path, csv_name = get_path_and_name_from_kwargs(name="tables/go_analysis_pvals", **kwargs)
+    save_csv_fn(save_path, csv_name, test_results_df)
+    #add extra col "background" to data frame - easier data handeling later
+    test_results_df.insert(0, "background", [1] * len(go_analysis_gene_names), True)
+
+    barwidth = 1 / (len(heights_df.columns) + 1)
+    max_prot_count = heights_df.max().max()
+    tick_y_pos = set()
+    fig, ax = plt.subplots(1, 1, figsize=(6, int(len(heights_df.columns) * len(go_analysis_gene_names)/1.5)))
+    #for every sample plot a single bar per go term selected in one subplot
+    for i, sample in enumerate(heights_df.columns):
+        width = 1 / (len(heights_df.columns) + 1) * i
+        y_pos = np.arange(len(heights_df)) + width
+        tick_y_pos.update(set(y_pos))
+        ax.barh(y=y_pos, width=heights_df[sample], height=barwidth, align="center", edgecolor='white')
+        #annotate each sample bar with the corresponding p valueis the p value is significant
+        for pval, x, y in zip(test_results_df[sample], heights_df[sample], y_pos):
+            if pval > 0.05:
                 continue
-            text = f"{text:.4f}" if text > 0.0005 else "< 0.0005"
-            ax.text(x, y, f" p: {text}", verticalalignment="center", fontsize="8")
-
-    ax.set_ylabel('compartiment')
-    ax.set_xlabel('number of proteins')
-    # add yticks on the middle of the group bars
-    ax.set_yticks([(len(heights) / 2 + (len(heights) + 1) * x) * bar_width
-                   for x in range(len(go_analysis_gene_names))])
-    # replace the y ticks with the compartiment names
-    ax.set_yticklabels([x for x in go_analysis_gene_names])
-    plt.legend()
+            text = f"{pval:.4f}" if pval > 0.0005 else "< 0.0005"
+            ax.annotate(f" p: {text}", xy=(x, y))
+    #annotate each set of bars for a go term with the corresponding go term label = second layer of y axis labeling
+    for i, go in enumerate(go_analysis_gene_names):
+        text = go.split(".txt")[0].replace("_", " ")
+        ax.annotate(text, xy=(-max_prot_count*0.4, i + 0.5-(1/(2*(len(heights_df.columns)+1)))),
+                    rotation=90, verticalalignment="center", annotation_clip=False)
 
+    ax.set_yticks(sorted(list(tick_y_pos)))
+    ax.set_yticklabels(list(heights_df.columns.values) * len(heights_df))
+    ax.set_xlim(0, max_prot_count + max_prot_count * 0.2)
+    ax.set_xlabel('Number of detected proteins from GO list')
     fig.tight_layout(rect=[0, 0.03, 1, 0.95])
+
     return fig, ax
 
 
+
 @save_plot("pathway_timecourse_{pathway}")
 def save_pathway_timecourse_results():
     """
@@ -1429,7 +1538,7 @@ def save_bar_venn(
     # initial figure setup
     fig, (ax1, ax2) = plt.subplots(2, 1, sharex=True, figsize=(1 * len(heights), 7))
     if show_suptitle:
-        fig.suptitle(ex, fontsize=20)
+        fig.suptitle(ex.replace("_", " "), fontsize=17, weight="bold")
     # create the bar plot
     ax1.bar(x, heights, color="skyblue")
     # add text to the bar plot
@@ -1437,13 +1546,16 @@ def save_bar_venn(
         ax1.text(x_level, max(heights) / 2, height, verticalalignment='center', horizontalalignment='center')
     ax1.set_ylabel("Number of proteins")
 
+    labels = [sample.split("_", 1)[1] if "_" in sample else sample for sample in y_mappings]
+    labels = [sample.replace("_", " ") for sample in labels]
+
     # create the line plots
     for x_level, y in zip(x, ys):
         # we just want to draw a straight line every time so we repeat x as often as needed
         ax2.plot([x_level] * len(y), y, linestyle="-", color="gray", marker=".")
     # replace the yticks with the names of the samples
-    ax2.set_yticks([i for i in range(len(y_mappings))])
-    ax2.set_yticklabels(y_mappings)
+    ax2.set_yticks([i for i in range(len(labels))])
+    ax2.set_yticklabels(labels)
     ax2.set_ylabel("Sample name")
     ax2.set_xlabel("Number of comparison")
 
@@ -1481,11 +1593,19 @@ def save_venn(
     plt.close("all")
     fig, ax = plt.subplots(1, 1, figsize=(14, 7))
     if show_suptitle:
-        plt.title(ex, fontsize=title_font_size)
+        plt.title(ex.replace("_", " "), fontsize=title_font_size, weight="bold")
 
     # create venn diagram based on size of set
     sets = named_sets.values()
     set_names = named_sets.keys()
+    split_names = False
+    for name in set_names:
+        if "_" in name:
+            split_names = True
+    if split_names:
+        set_names = [sample.split("_", 1)[1] for sample in set_names]
+    set_names = [name.replace("_", " ") for name in set_names]
+
     if len(sets) < 2:
         warnings.warn(f"Could not create venn diagram for {ex} because it has less than 2 replicates")
         return
